##
##  php-xdebug.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg    3.4.0
%define       V_subdir  3.4.0
%define       V_tarball 3.4.0

#   package information
Name:         php-xdebug
Summary:      Zend/PHP Debugger
URL:          http://xdebug.org/
Vendor:       Derick Rethans
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Language
License:      XDebug/PHP
Version:      %{V_opkg}
Release:      20241206

#   package options
%option       with_apache  yes

#   list of sources
Source0:      http://xdebug.org/files/xdebug-%{V_tarball}.tgz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, libtool, autoconf, automake
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  php
PreReq:       php
%if "%{with_apache}" == "yes"
PreReq:       apache, apache-php
%endif

%description
    The Xdebug PHP extension helps you debugging your script by
    providing a lot of valuable debug information. The debug information
    that Xdebug can provide includes the following: stack traces and
    function traces in error messages, memory allocation, protection for
    infinite recursions.

%track
    prog php-xdebug = {
        version   = %{V_tarball}
        url       = http://xdebug.org/download.php
        regex     = xdebug-(\d+\.\d+\.\d+)\.tgz
    }

%prep
    %setup -q -n xdebug-%{V_subdir}

%build
    #   configure module
    %{l_prefix}/bin/phpize
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --with-php-config=%{l_prefix}/bin/php-config \
        --enable-xdebug \
        --enable-shared \
        --disable-static

    #   build module
    %{l_make} %{l_mflags -O}

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/php-xdebug

    #   install module
    %{l_shtool} install -c -m 755 \
        .libs/xdebug.so $RPM_BUILD_ROOT%{l_prefix}/libexec/php-xdebug/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

